/****************************************************************************
** Meta object code from reading C++ file 'kdbusservice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdbusaddons-6.28.0/src/kdbusservice.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kdbusservice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KDBusServiceE_t {};
} // unnamed namespace

template <> constexpr inline auto KDBusService::qt_create_metaobjectdata<qt_meta_tag_ZN12KDBusServiceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDBusService",
        "activateRequested",
        "",
        "arguments",
        "workingDirectory",
        "openRequested",
        "QList<QUrl>",
        "uris",
        "activateActionRequested",
        "actionName",
        "QVariant",
        "parameter",
        "unregister",
        "StartupOption",
        "Unique",
        "Multiple",
        "NoExitOnFailure",
        "Replace",
        "StartupOptions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activateRequested'
        QtMocHelpers::SignalData<void(const QStringList &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'openRequested'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'activateActionRequested'
        QtMocHelpers::SignalData<void(const QString &, const QVariant &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'unregister'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'StartupOption'
        QtMocHelpers::EnumData<enum StartupOption>(13, 13, QMC::EnumFlags{}).add({
            {   14, StartupOption::Unique },
            {   15, StartupOption::Multiple },
            {   16, StartupOption::NoExitOnFailure },
            {   17, StartupOption::Replace },
        }),
        // flag 'StartupOptions'
        QtMocHelpers::EnumData<StartupOptions>(18, 13, QMC::EnumIsFlag).add({
            {   14, StartupOption::Unique },
            {   15, StartupOption::Multiple },
            {   16, StartupOption::NoExitOnFailure },
            {   17, StartupOption::Replace },
        }),
    };
    return QtMocHelpers::metaObjectData<KDBusService, qt_meta_tag_ZN12KDBusServiceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDBusService::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDBusServiceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDBusServiceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KDBusServiceE_t>.metaTypes,
    nullptr
} };

void KDBusService::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KDBusService *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activateRequested((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->openRequested((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 2: _t->activateActionRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 3: _t->unregister(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KDBusService::*)(const QStringList & , const QString & )>(_a, &KDBusService::activateRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDBusService::*)(const QList<QUrl> & )>(_a, &KDBusService::openRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDBusService::*)(const QString & , const QVariant & )>(_a, &KDBusService::activateActionRequested, 2))
            return;
    }
}

const QMetaObject *KDBusService::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDBusService::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KDBusServiceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDBusService::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KDBusService::activateRequested(const QStringList & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KDBusService::openRequested(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KDBusService::activateActionRequested(const QString & _t1, const QVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
