/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KDBusService.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KDBUSSERVICEEXTENSIONS_ADAPTOR_H
#define KDBUSSERVICEEXTENSIONS_ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "kdbusservice.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.KDBusService
 */
class KDBusServiceExtensionsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.KDBusService")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.KDBusService\">\n"
"    <method name=\"CommandLine\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"arguments\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"working-dir\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"platform-data\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"exit-status\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In2\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    KDBusServiceExtensionsAdaptor(KDBusService *parent);
    ~KDBusServiceExtensionsAdaptor() override;

    inline KDBusService *parent() const
    { return static_cast<KDBusService *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    int CommandLine(const QStringList &arguments, const QString &working_dir, const QVariantMap &platform_data);
Q_SIGNALS: // SIGNALS
};

#endif
