/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KDBusService.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kdbusserviceextensions_adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KDBusServiceExtensionsAdaptor
 */

KDBusServiceExtensionsAdaptor::KDBusServiceExtensionsAdaptor(KDBusService *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KDBusServiceExtensionsAdaptor::~KDBusServiceExtensionsAdaptor()
{
    // destructor
}

int KDBusServiceExtensionsAdaptor::CommandLine(const QStringList &arguments, const QString &working_dir, const QVariantMap &platform_data)
{
    // handle method call org.kde.KDBusService.CommandLine
    return parent()->CommandLine(arguments, working_dir, platform_data);
}


#include "moc_kdbusserviceextensions_adaptor.cpp"
