/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Application.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kdbusservice_adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KDBusServiceAdaptor
 */

KDBusServiceAdaptor::KDBusServiceAdaptor(KDBusService *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KDBusServiceAdaptor::~KDBusServiceAdaptor()
{
    // destructor
}

void KDBusServiceAdaptor::Activate(const QVariantMap &platform_data)
{
    // handle method call org.freedesktop.Application.Activate
    parent()->Activate(platform_data);
}

void KDBusServiceAdaptor::ActivateAction(const QString &action_name, const QVariantList &parameter, const QVariantMap &platform_data)
{
    // handle method call org.freedesktop.Application.ActivateAction
    parent()->ActivateAction(action_name, parameter, platform_data);
}

void KDBusServiceAdaptor::Open(const QStringList &uris, const QVariantMap &platform_data)
{
    // handle method call org.freedesktop.Application.Open
    parent()->Open(uris, platform_data);
}


#include "moc_kdbusservice_adaptor.cpp"
